@@ -48,10 +48,33 @@ class BotMaestroSDK:
         Attributes:
             access_token (str): The access token obtained via login.
         """
-        self._server = server
+        self._server = None
         self._login = login
         self._key = key
-        self.access_token = None
+        self._access_token = None
+
+        self.server = server
+
+    @property
+    def server(self):
+        """The server address"""
+        return self._server
+
+    @server.setter
+    def server(self, server):
+        # Remove additional end /
+        if server and server[-1] == "/":
+            server = server[:-1]
+        self._server = server
+
+    @property
+    def access_token(self):
+        """The access token"""
+        return self._access_token
+
+    @access_token.setter
+    def access_token(self, token):
+        self._access_token = token
 
     def login(self, server: Optional[str] = None, login: Optional[str] = None, key: Optional[str] = None):
         """
@@ -65,7 +88,8 @@ class BotMaestroSDK:
             key: The access key provided via server configuration. Available under `Dev. Environment`
 
         """
-        self._server = server or self._server
+        if server:
+            self.server = server
         self._login = login or self._login
         self._key = key or self._key
         if not self._server:
@@ -120,7 +144,7 @@ class BotMaestroSDK:
 
     @ensure_access_token
     def message(self, email: List[str], users: List[str], subject: str, body: str,
-                msg_type: model.MessageType, group: str) -> model.ServerMessage:
+                msg_type: model.MessageType, group: Optional[str] = None) -> model.ServerMessage:
         """
         Send an email message to the list of email and users given.
 
@@ -137,6 +161,9 @@ class BotMaestroSDK:
         """
         url = f'{self._server}/app/api/message/send'
 
+        if not group:
+            group = ""
+
         email_str = ",".join(email)
         users_str = ",".join(users)
 
@@ -365,7 +392,7 @@ class BotMaestroSDK:
         """
         # date  a partir desta data
         # date em branco eh tudo
-        url = f'{self._server}/app/api/log/read'
+        url = f'{self._server}/app/api/log/delete'
 
         data = {"activityLabel": activity_label, "access_token": self.access_token}
         with requests.post(url, data=data) as req:
@@ -418,6 +445,36 @@ class BotMaestroSDK:
                     message = 'Error during artifact posting. Server returned %d. %s' % (req.status_code, req.text)
                 raise ValueError(message)
 
+    @ensure_access_token
+    def list_artifacts(self) -> List[model.Artifact]:
+        """
+        List all artifacts available for the organization.
+
+        Returns:
+            List of artifacts. See [Artifact][botcity.maestro.model.Artifact]
+        """
+        url = f'{self._server}/app/api/artifact/list'
+
+        data = {
+            "access_token": self.access_token
+        }
+
+        with requests.get(url, params=data) as req:
+            if req.status_code == 200:
+                data = json.loads(req.text)
+                message = data.get("message", "")
+                if not message:
+                    return []
+
+                return [model.Artifact.from_dict(a) for a in json.loads(message)]
+            else:
+                try:
+                    message = 'Error during artifact listing. Server returned %d. %s' % (
+                        req.status_code, req.json().get('message', ''))
+                except ValueError:
+                    message = 'Error during artifact listing. Server returned %d. %s' % (req.status_code, req.text)
+                raise ValueError(message)
+
     @ensure_access_token
     def get_artifact(self, artifact_id: int) -> Tuple[str, bytes]:
         """
@@ -436,6 +493,7 @@ class BotMaestroSDK:
         with requests.get(url, params=data) as req:
             if req.status_code == 200:
                 h_content = req.headers['Content-Disposition']
+
                 filename = h_content[h_content.rfind('=') + 2:-1]
                 filename = filename[:filename.rfind('_')] + filename[filename.rfind('.'):]
                 return filename, req.content
